@@ -139,9 +139,12 @@ impl ArgMatches {
     /// ```
     #[cfg_attr(debug_assertions, track_caller)]
     pub fn get_count(&self, id: &str) -> u8 {
-        *self
-            .get_one::<u8>(id)
-            .expect("ArgAction::Count is defaulted")
+        *self.get_one::<u8>(id).unwrap_or_else(|| {
+            panic!(
+                "arg `{}`'s `ArgAction` should be `Count` which should provide a default",
+                id
+            )
+        })
     }
 
     /// Gets the value of a specific [`ArgAction::SetTrue`][crate::ArgAction::SetTrue] or [`ArgAction::SetFalse`][crate::ArgAction::SetFalse] flag
@@ -173,7 +176,12 @@ impl ArgMatches {
     pub fn get_flag(&self, id: &str) -> bool {
         *self
             .get_one::<bool>(id)
-            .expect("ArgAction::SetTrue / ArgAction::SetFalse is defaulted")
+            .unwrap_or_else(|| {
+                panic!(
+                    "arg `{}`'s `ArgAction` should be one of `SetTrue`, `SetFalse` which should provide a default",
+                    id
+                )
+            })
     }
 
     /// Iterate over values of a specific option or positional argument.
@@ -246,7 +254,6 @@ impl ArgMatches {
     /// assert_eq!(vals, [["a", "b"], ["c", "d"]]);
     /// ```
     #[cfg_attr(debug_assertions, track_caller)]
-    #[cfg(feature = "unstable-grouped")]
     pub fn get_occurrences<T: Any + Clone + Send + Sync + 'static>(
         &self,
         id: &str,
@@ -348,7 +355,6 @@ impl ArgMatches {
     /// [`OsStr`]: std::ffi::OsStr
     /// [values]: OsValues
     /// [`String`]: std::string::String
-    #[cfg(feature = "unstable-grouped")]
     #[cfg_attr(debug_assertions, track_caller)]
     pub fn get_raw_occurrences(&self, id: &str) -> Option<RawOccurrences<'_>> {
         MatchesError::unwrap(id, self.try_get_raw_occurrences(id))
@@ -460,7 +466,6 @@ impl ArgMatches {
     /// let vals: Vec<Vec<String>> = m.remove_occurrences("x").unwrap().map(Iterator::collect).collect();
     /// assert_eq!(vals, [["a", "b"], ["c", "d"]]);
     /// ```
-    #[cfg(feature = "unstable-grouped")]
     #[cfg_attr(debug_assertions, track_caller)]
     pub fn remove_occurrences<T: Any + Clone + Send + Sync + 'static>(
         &mut self,
@@ -476,7 +481,7 @@ impl ArgMatches {
     ///
     /// # Panics
     ///
-    /// If `id` is is not a valid argument or group name.  To handle this case programmatically, see
+    /// If `id` is not a valid argument or group name.  To handle this case programmatically, see
     /// [`ArgMatches::try_contains_id`].
     ///
     /// # Examples
@@ -602,7 +607,7 @@ impl ArgMatches {
     ///
     /// # Panics
     ///
-    /// If `id` is is not a valid argument or group id.
+    /// If `id` is not a valid argument or group id.
     ///
     /// # Examples
     ///
@@ -648,7 +653,7 @@ impl ArgMatches {
     ///
     /// # Panics
     ///
-    /// If `id` is is not a valid argument or group id.
+    /// If `id` is not a valid argument or group id.
     ///
     /// # Examples
     ///
@@ -791,7 +796,7 @@ impl ArgMatches {
     ///
     /// # Panics
     ///
-    /// If `id` is is not a valid argument or group id.
+    /// If `id` is not a valid argument or group id.
     ///
     /// # Examples
     ///
@@ -988,7 +993,7 @@ impl ArgMatches {
     ///
     /// # Panics
     ///
-    /// If `id` is is not a valid subcommand.
+    /// If `id` is not a valid subcommand.
     ///
     /// # Examples
     ///
@@ -1008,7 +1013,7 @@ impl ArgMatches {
     ///     ]);
     ///
     /// // Both parent commands, and child subcommands can have arguments present at the same times
-    /// assert!(*app_m.get_one::<bool>("debug").expect("defaulted by clap"));
+    /// assert!(app_m.get_flag("debug"));
     ///
     /// // Get the subcommand's ArgMatches instance
     /// if let Some(sub_m) = app_m.subcommand_matches("test") {
@@ -1110,7 +1115,6 @@ impl ArgMatches {
     }
 
     /// Non-panicking version of [`ArgMatches::get_occurrences`]
-    #[cfg(feature = "unstable-grouped")]
     pub fn try_get_occurrences<T: Any + Clone + Send + Sync + 'static>(
         &self,
         id: &str,
@@ -1143,7 +1147,6 @@ impl ArgMatches {
     }
 
     /// Non-panicking version of [`ArgMatches::get_raw_occurrences`]
-    #[cfg(feature = "unstable-grouped")]
     pub fn try_get_raw_occurrences(
         &self,
         id: &str,
@@ -1196,7 +1199,6 @@ impl ArgMatches {
     }
 
     /// Non-panicking version of [`ArgMatches::remove_occurrences`]
-    #[cfg(feature = "unstable-grouped")]
     pub fn try_remove_occurrences<T: Any + Clone + Send + Sync + 'static>(
         &mut self,
         id: &str,
@@ -1308,10 +1310,9 @@ impl ArgMatches {
             if arg == Id::EXTERNAL || self.valid_args.iter().any(|s| *s == arg) {
             } else {
                 panic!(
-                    "`{:?}` is not an id of an argument or a group.\n\
+                    "`{arg:?}` is not an id of an argument or a group.\n\
                      Make sure you're using the name of the argument itself \
-                     and not the name of short or long flags.",
-                    arg
+                     and not the name of short or long flags."
                 );
             }
         }
@@ -1326,7 +1327,7 @@ impl ArgMatches {
         {
             if name.is_empty() || self.valid_subcommands.iter().any(|s| *s == name) {
             } else {
-                panic!("`{}` is not a name of a subcommand.", name);
+                panic!("`{name}` is not a name of a subcommand.");
             }
         }
 
@@ -1868,9 +1869,9 @@ impl<'a> Default for Indices<'a> {
     }
 }
 
-#[cfg(feature = "unstable-grouped")]
 #[cfg_attr(debug_assertions, track_caller)]
 #[inline]
+#[cfg(feature = "unstable-grouped")]
 fn unwrap_string(value: &AnyValue) -> &str {
     match value.downcast_ref::<String>() {
         Some(value) => value,
