@@ -82,7 +82,7 @@ impl std::str::FromStr for ColorChoice {
                 return Ok(*variant);
             }
         }
-        Err(format!("Invalid variant: {}", s))
+        Err(format!("invalid variant: {s}"))
     }
 }
 
